interface Logger {
    /**
     * A logger instance. Similar to console logger with some more context.
     *
     * @param message log message.
     * @param optionalParams objects with which to replace substitution strings
     * within message. This gives you additional control over the format of the
     * output.
     */
    (message?: any, ...optionalParams: any[]): void;
}
declare type Level = "debug" | "info" | "warn" | "error";
/**
 * Create a logger with some context. A context can be metadata relating to the
 * log or some other useful information. It will be logged inline with the log
 * line.
 *
 * @param context an object containing the metadata.
 * @returns an object of loggers.
 */
export declare const logger: {
    debug: Logger;
    info: Logger;
    warn: Logger;
    error: Logger;
    with: (context: {
        [key: string]: any;
    }) => {
        debug: Logger;
        info: Logger;
        warn: Logger;
        error: Logger;
    };
};
export {};
