"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.logger = void 0;
const ansi = (code, message) => ["\x1b[", code, "m", message, "\x1b[0m"].join("");
const zeroPad = (value, limit = 10) => value < limit ? `0${value}` : value.toString();
const formattedTime = (now) => ansi(2, [
    [now.getFullYear(), zeroPad(now.getMonth()), zeroPad(now.getDate())].join("-"),
    [
        [now.getHours(), now.getMinutes(), now.getSeconds()]
            .map((digit) => zeroPad(digit))
            .join(":"),
        zeroPad(now.getMilliseconds(), 100),
    ].join("."),
].join(" "));
const formattedLogLevel = (level) => {
    switch (level) {
        case "debug":
            return ansi(32, "debug");
        case "info":
            return ansi(34, " info");
        case "warn":
            return ansi(33, " warn");
        case "error":
            return ansi(31, "error");
    }
};
const formattedContext = (context) => Object.keys(context)
    .map((key) => ansi(2, `[${key}=${context[key]}]`))
    .join(" ");
const logPrefix = (level, context) => [
    formattedTime(new Date()),
    formattedLogLevel(level),
    formattedContext(context),
    ansi(2, ":"),
]
    .filter((component) => component)
    .join(" ");
const contextLogger = (context) => ({
    debug: (message, ...optionalParams) => console.debug(logPrefix("debug", context), message, ...optionalParams),
    info: (message, ...optionalParams) => console.info(logPrefix("info", context), message, ...optionalParams),
    warn: (message, ...optionalParams) => console.warn(logPrefix("warn", context), message, ...optionalParams),
    error: (message, ...optionalParams) => console.error(logPrefix("error", context), message, ...optionalParams),
});
/**
 * Create a logger with some context. A context can be metadata relating to the
 * log or some other useful information. It will be logged inline with the log
 * line.
 *
 * @param context an object containing the metadata.
 * @returns an object of loggers.
 */
exports.logger = { with: contextLogger, ...contextLogger({}) };
//# sourceMappingURL=index.js.map